@@ -90,7 +90,10 @@ class DatabaseObject:
 
     def __init__(self, row):
         self.row = row
-        
+
+        if not self.fields:
+            self.fields = DatabaseObject.get_description(self)
+
         for i, field in enumerate(self.fields):
             setattr(self, field, self.row[i])
 
